Screen enum
Values
- initialization → const Screen
- onboarding → const Screen
- measurement → const Screen
- instructions → const Screen
- results → const Screen
- healthRisks → const Screen
- healthRisksEdit → const Screen
- calibrationOnboarding → const Screen
- calibrationFinish → const Screen
- calibrationDataEntry → const Screen
- disclaimer → const Screen
- dashboard → const Screen
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited