CustomMeasurementConfigInternal class
Constructors
Properties
- durationSeconds ↔ double?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
healthIndices
↔ List<
int?> ? -
getter/setter pair
- infiniteMeasurement ↔ bool?
-
getter/setter pair
-
instantMetrics
↔ List<
int?> ? -
getter/setter pair
- realtimeCardiacStressPeriodSeconds ↔ double?
-
getter/setter pair
- realtimeHrPeriodSeconds ↔ double?
-
getter/setter pair
- realtimeHrvPeriodSeconds ↔ double?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
summaryMetrics
↔ List<
int?> ? -
getter/setter pair
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object result) → CustomMeasurementConfigInternal